==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nl_NL\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  ""
 ,""

]
, "Sync Devices"
: "Sync Apparaten"

, "ID"
: "ID"

, "Device ID"
: "Apparaat ID"

, "Devicetype"
: "Apparaattype"

, "Owner"
: "Eigenaar"

, "Policy"
: "Beleid"

, "AS Version"
: "AS Versie"

, "Useragent"
: "Gebruikersagent"

, "Model"
: "Model"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Vriendelijke naam"

, "OS"
: "OS"

, "OS Language"
: "OS Taal"

, "Phonenumber"
: "Telefoonnummer"

, "Ping Lifetime"
: "Ping lifetime"

, "Ping Folder"
: "Ping Map"

, "Remote Wipe"
: "Van afstand wissen"

, "Calendarfilter"
: "Kalenderfilter"

, "Contactsfilter"
: "Contactfilter"

, "Emailfilter"
: "Emailfilter"

, "Tasksfilter"
: "Taakfilter"

, "Last Ping"
: "Laatste Ping"

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: "Snelzoeken"

, "Device, Devices"
: [
  "Apparaat"
 ,"Apparaten"

]
, "Devices"
: "Apparaten"

, "Active Sync"
: "ActiveSync"

, "Select a Device"
: "Selecteer een apparaat"

, "No ActiveSync Device registered"
: "Geen ActiveSync apparaat geregistreerd"

, "Set as {0} Filter"
: "Stel {0} in als filter"

, "Resetted Sync Filter"
: "Reset Sync filter"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter voor apparaat \"{1}\" is nu \"{2}\""

, "resetted"
: "Hersteld"

, "Set Sync Filter"
: "Zet Sync filter"

, "Default Addressbook"
: "Standaard adresboek"

, "The default addressbook to create new contacts in."
: "Het standaard adresboek waar nieuwe contacten in komen."

, "Default Calendar"
: "Standaard agenda"

, "The default calendar to create new events in."
: "De standaard agenda waar nieuwe gebeurtenissen in komen"

, "Default Task List"
: "Standaard taaklijst"

, "The default task list to create new tasks in."
: "De standaard taaklijst waar nieuwe taken in komen"

, "Default policy for new devices"
: "Standaard gedragslijn voor nieuwe apparaten"

, "Enter the id of the policy to apply to newly created devices."
: "Voer het ID van de op nieuwe apparaten van toepassing gedagslijn in"

, "Disable Access Log"
: "Schakel Toegangs log uit"

, "Disable ActiveSync Access Log creation."
: "Schakel ActiveSync Toegangslog uit."

, "Filter timeslot for emails"
: "Filter tijdslot voor emails"

, "For how long in the past the emails should be synchronized."
: "Hoelang terug moeten emails worden gesynchroniseerd."

, "Filter timeslot for events"
: "Filter tijdslot voor afspraken"

, "For how long in the past the events should be synchronized."
: "Hoelang terug moeten afspraken worden gesynchroniseerd."

, "Manage ActiveSync devices"
: "Beheer ActiveSync apparaten"

, "See, edit and delete ActiveSync devices"
: "Bekijk, pas aan en verwijder ActiveSync apparaten"

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: "Standaard gedragslijn"

, "Default Policy installed during setup"
: "Standaard gedragslijn ingesteld tijdens de installatie"

, "SyncDevice"
: ""

, "Device"
: "Apparaat"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: ActiveSync/js/ActiveSync-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Standaard agenda"

, "The default calendar to create new events in."
: "De standaard agenda waar nieuwe gebeurtenissen in komen"

, "Default Task List"
: "Standaard taaklijst"

, "The default task list to create new tasks in."
: "De standaard taaklijst waar nieuwe taken in komen"

, "Sync Devices"
: "Sync Apparaten"

, "Device ID"
: "Apparaat ID"

, "Devicetype"
: "Apparaattype"

, "Owner"
: "Eigenaar"

, "Policy"
: "Beleid"

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: "Model"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Vriendelijke naam"

, "OS"
: "OS"

, "OS Language"
: "OS Taal"

, "Phonenumber"
: "Telefoonnummer"

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Apparaat"
 ,"Apparaten"

]
, "Devices"
: "Apparaten"

, "Active Sync"
: "ActiveSync"

, "Select a Device"
: "Selecteer een apparaat"

, "No ActiveSync Device registered"
: "Geen ActiveSync apparaat geregistreerd"

, "Set as {0} Filter"
: "Stel {0} in als filter"

, "Resetted Sync Filter"
: "Reset Sync filter"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter voor apparaat \"{1}\" is nu \"{2}\""

, "resetted"
: "Hersteld"

, "Set Sync Filter"
: "Zet Sync filter"

, "ID"
: "ID"

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: "Ping lifetime"

, "Ping Folder"
: "Ping Map"

, "Remote Wipe"
: "Van afstand wissen"

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: "Laatste Ping"

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: "Snelzoeken"

, "Default Policy"
: "Standaard gedragslijn"

, "Default Policy installed during setup"
: "Standaard gedragslijn ingesteld tijdens de installatie"

, "Default policy for new devices"
: "Standaard gedragslijn voor nieuwe apparaten"

, "Enter the id of the policy to apply to newly created devices."
: "Voer het ID van de op nieuwe apparaten van toepassing gedagslijn in"

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Schakel Toegangs log uit"

, "Disable ActiveSync Access Log creation."
: "Schakel ActiveSync Toegangslog uit."

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Filter tijdslot voor afspraken"

, "For how long in the past the events should be synchronized."
: "Hoelang terug moeten afspraken worden gesynchroniseerd."

, "Manage ActiveSync devices"
: "Beheer ActiveSync apparaten"

, "See, edit and delete ActiveSync devices"
: "Bekijk, pas aan en verwijder ActiveSync apparaten"

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""











, "Sync Device"
: ""

, "Device"
: "Apparaat"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
